@@ -15,6 +15,8 @@ import numpy as np
 from pkshared.tools.refdata import atomic_masses, atomic_mass_symbol_map, \
     atomic_numbers, atomic_number_symbol_map, element_symbols
 
+__all__ = ['Atom', 'AtomAttributes']
+
 
 class AtomAttributes(object):
     pass
@@ -22,7 +24,7 @@ class AtomAttributes(object):
 
 class Atom(object):
 
-    """Class for creating abstract object representing an Atom.
+    """Class for creating abstract object representing an `Atom`.
 
     Parameters
     ----------
@@ -36,7 +38,7 @@ class Atom(object):
     atomtype : int, optional
         atom type, a LAMMPS atom attribute.
     q : {int, float}, optional
-        Net charge of Atom.
+        Net charge of `Atom`.
     x, y, z : float, optional
         :math:`x, y, z` components of position.
     vx, vy, vz : float, optional
@@ -48,14 +50,16 @@ class Atom(object):
     nx, ny, nz : int, optional
         :math:`n_x, n_y, n_z` image flags for LAMMPS atoms.
     CN : int, optional
-        Atom coordination number.
+        `Atom` coordination number.
+    NN : `Atoms`, optional
+        Nearest-neighbor `Atoms` object instance
 
     """
 
     def __init__(self, element=None, atomID=0, moleculeID=0, atomtype=1, q=0.,
                  mass=None, x=None, y=None, z=None, vx=None, vy=None, vz=None,
                  r_units=None, v_units=None, nx=None, ny=None, nz=None,
-                 CN=None):
+                 CN=None, NN=None):
 
         self._symbol = None
         self._Z = None
@@ -126,9 +130,10 @@ class Atom(object):
         self._atomtype = int(atomtype)
 
         self._CN = CN
+        self._NN = NN
 
         self._attributes = ['symbol', 'Z', 'm', 'q', 'r', 'v', 'atomID',
-                            'moleculeID', 'atomtype', 'CN']
+                            'moleculeID', 'atomtype', 'CN', 'NN']
 
     def __str__(self):
         """Return string representation of atom."""
@@ -145,14 +150,24 @@ class Atom(object):
 
     @property
     def CN(self):
-        """Coordination number."""
+        """Return `Atom` coordination number."""
         return self._CN
 
     @CN.setter
     def CN(self, value=int):
-        """Set coordination number."""
+        """Set `Atom` coordination number."""
         self._CN = int(value)
 
+    @property
+    def NN(self):
+        """Return list of nearest-neighbor `Atom` objects."""
+        return self._NN
+
+    @NN.setter
+    def NN(self, value=list):
+        """Set list of nearest-neighbor `Atom` objects."""
+        self._NN = value
+
     @property
     def Z(self):
         """Atomic number :math:`Z`.
@@ -200,7 +215,7 @@ class Atom(object):
 
     @x.setter
     def x(self, value=float):
-        """Set Atom :math:`x`-coordinate in units of **Angstroms**.
+        """Set `Atom` :math:`x`-coordinate in units of **Angstroms**.
 
         Parameters
         ----------
@@ -225,7 +240,7 @@ class Atom(object):
 
     @y.setter
     def y(self, value=float):
-        """Set Atom :math:`y`-coordinate in units of **Angstroms**.
+        """Set `Atom` :math:`y`-coordinate in units of **Angstroms**.
 
         Parameters
         ----------
@@ -250,7 +265,7 @@ class Atom(object):
 
     @z.setter
     def z(self, value=float):
-        """Set Atom :math:`z`-coordinate in units of **Angstroms**.
+        """Set `Atom` :math:`z`-coordinate in units of **Angstroms**.
 
         Parameters
         ----------
@@ -269,7 +284,7 @@ class Atom(object):
         -------
         ndarray
             3-element ndarray of [:math:`x, y, z`] coordinates
-            of Atom.
+            of `Atom`.
 
         """
         return self._r
@@ -298,7 +313,7 @@ class Atom(object):
 
     @q.setter
     def q(self, value=float):
-        """Set Atom charge :math:`q`.
+        """Set `Atom` charge :math:`q`.
 
         Parameters
         ----------
@@ -312,7 +327,7 @@ class Atom(object):
 
     @property
     def atomID(self):
-        """Atom ID (*LAMMPS atom attribute*)."""
+        """`Atom` ID (*LAMMPS atom attribute*)."""
         return self._atomID
 
     @atomID.setter
@@ -348,7 +363,7 @@ class Atom(object):
 
     @property
     def atomtype(self):
-        """Atom type (*LAMMPS atom attribute*)."""
+        """`Atom` type (*LAMMPS atom attribute*)."""
         return self._atomtype
 
     @atomtype.setter
@@ -366,24 +381,24 @@ class Atom(object):
 
     @property
     def vx(self):
-        """:math:`v_x` component in units of ``v_units``.
+        """:math:`v_x` component in units of `v_units`.
 
         Returns
         -------
         float
-            :math:`v_x` component in units of ``v_units``.
+            :math:`v_x` component in units of `v_units`.
 
         """
         return self._v[0]
 
     @vx.setter
     def vx(self, value=float):
-        """Set Atom :math:`v_x` component.
+        """Set `Atom` :math:`v_x` component.
 
         Parameters
         ----------
         value : float
-            :math:`v_x` component in units of ``v_units``.
+            :math:`v_x` component in units of `v_units`.
 
         """
         self._check_type(value, (int, float))
@@ -391,24 +406,24 @@ class Atom(object):
 
     @property
     def vy(self):
-        """:math:`v_y` component in units of ``v_units``.
+        """:math:`v_y` component in units of `v_units`.
 
         Returns
         -------
         float
-            :math:`v_y` component in units of ``v_units``.
+            :math:`v_y` component in units of `v_units`.
 
         """
         return self._v[1]
 
     @vy.setter
     def vy(self, value=float):
-        """Set Atom :math:`v_y` component.
+        """Set `Atom` :math:`v_y` component.
 
         Parameters
         ----------
         value : float
-            :math:`v_y` component in units of ``v_units``.
+            :math:`v_y` component in units of `v_units`.
 
         """
         self._check_type(value, (int, float))
@@ -416,24 +431,24 @@ class Atom(object):
 
     @property
     def vz(self):
-        """:math:`v_z` component in units of ``v_units``.
+        """:math:`v_z` component in units of `v_units`.
 
         Returns
         -------
         float
-            :math:`v_z` component in units of ``v_units``.
+            :math:`v_z` component in units of `v_units`.
 
         """
         return self._v[2]
 
     @vz.setter
     def vz(self, value=float):
-        """Set Atom :math:`v_z` component.
+        """Set `Atom` :math:`v_z` component.
 
         Parameters
         ----------
         value : float
-            :math:`v_z` component in units of ``v_units``.
+            :math:`v_z` component in units of `v_units`.
 
         """
         self._check_type(value, (int, float))
@@ -447,20 +462,20 @@ class Atom(object):
         -------
         ndarray
             3-element ndarray of [:math:`v_x`, :math:`v_y`, :math:`v_z`]
-            velocity components of Atom.
+            velocity components of `Atom`.
 
         """
         return self._v
 
     @v.setter
     def v(self, value=np.ndarray):
-        """Set :math:`x, y, z` components of Atom velocity.
+        """Set :math:`x, y, z` components of `Atom` velocity.
 
         Parameters
         ----------
         value : array_like
             3-element ndarray of [:math:`v_x`, :math:`v_y`, :math:`v_z`]
-            velocity components of Atom.
+            velocity components of `Atom`.
 
         """
         self._check_type(value, np.ndarray)
@@ -531,7 +546,7 @@ class Atom(object):
 
     @nz.setter
     def nz(self, value=int):
-        """Set Atom :math:`n_z` image flag.
+        """Set `Atom` :math:`n_z` image flag.
 
         Parameters
         ----------
@@ -544,26 +559,26 @@ class Atom(object):
 
     @property
     def n(self):
-        """:math:`n_x, n_y, n_z` image flags of Atom.
+        """:math:`n_x, n_y, n_z` image flags of `Atom`.
 
         Returns
         -------
         ndarray
             3-element ndarray of [:math:`n_x`, :math:`n_y`, :math:`n_z`]
-            image flags of Atom.
+            image flags of `Atom`.
 
         """
         return self._n
 
     @n.setter
     def n(self, value=np.ndarray):
-        """Set :math:`n_x, n_y, n_z` image flags of Atom.
+        """Set :math:`n_x, n_y, n_z` image flags of `Atom`.
 
         Parameters
         ----------
         value : array_like
             3-element ndarray of [:math:`n_x`, :math:`n_y`, :math:`n_z`]
-            image flags of Atom.
+            image flags of `Atom`.
 
         """
         self._check_type(value, np.ndarray)
@@ -586,7 +601,7 @@ class Atom(object):
         """
         r = self._r.tolist()
         for i, ri in enumerate(r[:]):
-            if abs(ri) < epsilon:
+            if ri < 0 and abs(ri) < epsilon:
                 r[i] = 0.0
         self._r[0], self._r[1], self._r[2] = r
 
